@@ -2,23 +2,10 @@
  *
  * Copyright (C) 2012-2017 Richard Hughes <richard@hughsie.com>
  *
- * Licensed under the GNU General Public License Version 2
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0+
  */
 
+#pragma once
 
 /**
  * SECTION:gs-plugin-vfuncs
@@ -28,9 +15,6 @@
  * @short_description: Vfuncs that plugins can implement
  */
 
-#ifndef __GS_PLUGIN_VFUNCS_H
-#define __GS_PLUGIN_VFUNCS_H
-
 #include <appstream-glib.h>
 #include <glib-object.h>
 #include <gmodule.h>
@@ -40,7 +24,6 @@
 #include "gs-app.h"
 #include "gs-app-list.h"
 #include "gs-category.h"
-#include "gs-price.h"
 
 G_BEGIN_DECLS
 
@@ -146,6 +129,27 @@ gboolean	 gs_plugin_add_search_what_provides	(GsPlugin	*plugin,
 							 GCancellable	*cancellable,
 							 GError		**error);
 
+/**
+ * gs_plugin_add_alternates
+ * @plugin: a #GsPlugin
+ * @app: a #GsApp
+ * @list: a #GsAppList
+ * @cancellable: a #GCancellable, or %NULL
+ * @error: a #GError, or %NULL
+ *
+ * Called when trying to find alternates to a specific app, for instance
+ * finding a flatpak version of an existing distro packaged application.
+ *
+ * Plugins are expected to add new apps using gs_app_list_add().
+ *
+ * Returns: %TRUE for success or if not relevant
+ **/
+gboolean	 gs_plugin_add_alternates		(GsPlugin	*plugin,
+							 GsApp		*app,
+							 GsAppList	*list,
+							 GCancellable	*cancellable,
+							 GError		**error);
+
 /**
  * gs_plugin_setup:
  * @plugin: a #GsPlugin
@@ -195,7 +199,7 @@ gboolean	 gs_plugin_add_installed		(GsPlugin	*plugin,
  * Get the list of updates.
  *
  * NOTE: Actually downloading the updates can be done in gs_plugin_download_app()
- * or in gs_plugin_update_app().
+ * or in gs_plugin_download().
  *
  * Plugins are expected to add new apps using gs_app_list_add().
  *
@@ -541,27 +545,6 @@ gboolean	 gs_plugin_update_cancel		(GsPlugin	*plugin,
 							 GCancellable	*cancellable,
 							 GError		**error);
 
-/**
- * gs_plugin_app_purchase:
- * @plugin: a #GsPlugin
- * @app: a #GsApp
- * @price: a #GsPrice
- * @cancellable: a #GCancellable, or %NULL
- * @error: a #GError, or %NULL
- *
- * Purchase the application.
- *
- * NOTE: Once the action is complete, the plugin must set the new state of @app
- * to %AS_APP_STATE_AVAILABLE.
- *
- * Returns: %TRUE for success or if not relevant
- **/
-gboolean	 gs_plugin_app_purchase			(GsPlugin	*plugin,
-							 GsApp		*app,
-							 GsPrice	*price,
-							 GCancellable	*cancellable,
-							 GError		**error);
-
 /**
  * gs_plugin_app_install:
  * @plugin: a #GsPlugin
@@ -660,7 +643,7 @@ gboolean	 gs_plugin_app_set_rating		(GsPlugin	*plugin,
  * NOTE: Once the action is complete, the plugin must set the new state of @app
  * to %AS_APP_STATE_INSTALLED or %AS_APP_STATE_UNKNOWN if not known.
  *
- * If %AS_APP_QUIRK_IS_PROXY is set on the application then the actual #GsApp
+ * If %GS_APP_QUIRK_IS_PROXY is set on the application then the actual #GsApp
  * set in @app will be the related application of the parent. Plugins do not
  * need to manually iterate on the related list of applications.
  *
@@ -681,6 +664,11 @@ gboolean	 gs_plugin_update_app			(GsPlugin	*plugin,
  * Downloads the application and any dependencies ready to be installed or
  * updated.
  *
+ * Plugins are expected to schedule downloads using the system download
+ * scheduler if appropriate (if the download is not guaranteed to be under a few
+ * hundred kilobytes, for example), so that the user’s metered data preferences
+ * are honoured.
+ *
  * Plugins are expected to send progress notifications to the UI using
  * gs_app_set_progress() using the passed in @app.
  *
@@ -709,6 +697,11 @@ gboolean	 gs_plugin_download_app			(GsPlugin	*plugin,
  *
  * Downloads a list of applications ready to be installed or updated.
  *
+ * Plugins are expected to schedule downloads using the system download
+ * scheduler if appropriate (if the download is not guaranteed to be under a few
+ * hundred kilobytes, for example), so that the user’s metered data preferences
+ * are honoured.
+ *
  * Returns: %TRUE for success or if not relevant
  **/
 gboolean	 gs_plugin_download			(GsPlugin	*plugin,
@@ -902,7 +895,7 @@ gboolean	 gs_plugin_refresh			(GsPlugin	*plugin,
  * list. If no plugins can handle the file, the list will be empty.
  *
  * For example, the PackageKit plugin can turn a .rpm file into a application
- * of kind %AS_APP_KIND_UNKNOWN but that in some cases it will be futher refined
+ * of kind %AS_APP_KIND_UNKNOWN but that in some cases it will be further refined
  * into a %AS_APP_KIND_DESKTOP (with all the extra metadata) by the appstream
  * plugin.
  *
@@ -957,71 +950,21 @@ gboolean	 gs_plugin_update			(GsPlugin	*plugin,
 							 GError		**error);
 
 /**
- * gs_plugin_auth_login:
+ * gs_plugin_add_langpacks:
  * @plugin: a #GsPlugin
- * @auth: a #GsAuth
+ * @list: a #GsAppList
+ * @locale: a #LANGUAGE_CODE or #LOCALE, e.g. "ja" or "ja_JP"
  * @cancellable: a #GCancellable, or %NULL
  * @error: a #GError, or %NULL
  *
- * Performs a login using the given authentication details.
+ * Returns a list of language packs, as per input language code or locale.
  *
  * Returns: %TRUE for success or if not relevant
  **/
-gboolean	 gs_plugin_auth_login			(GsPlugin	*plugin,
-							 GsAuth		*auth,
-							 GCancellable	*cancellable,
-							 GError		**error);
-
-/**
- * gs_plugin_auth_logout:
- * @plugin: a #GsPlugin
- * @auth: a #GsAuth
- * @cancellable: a #GCancellable, or %NULL
- * @error: a #GError, or %NULL
- *
- * Performs a logout using the given authentication details.
- *
- * Returns: %TRUE for success or if not relevant
- **/
-gboolean	 gs_plugin_auth_logout			(GsPlugin	*plugin,
-							 GsAuth		*auth,
-							 GCancellable	*cancellable,
-							 GError		**error);
-
-/**
- * gs_plugin_auth_lost_password:
- * @plugin: a #GsPlugin
- * @auth: a #GsAuth
- * @cancellable: a #GCancellable, or %NULL
- * @error: a #GError, or %NULL
- *
- * Performs the lost password action using the given authentication details.
- *
- * Returns: %TRUE for success or if not relevant
- **/
-gboolean	 gs_plugin_auth_lost_password		(GsPlugin	*plugin,
-							 GsAuth		*auth,
-							 GCancellable	*cancellable,
-							 GError		**error);
-
-/**
- * gs_plugin_auth_register:
- * @plugin: a #GsPlugin
- * @auth: a #GsAuth
- * @cancellable: a #GCancellable, or %NULL
- * @error: a #GError, or %NULL
- *
- * Performs the registration action using the given authentication details.
- *
- * Returns: %TRUE for success or if not relevant
- **/
-gboolean	 gs_plugin_auth_register		(GsPlugin	*plugin,
-							 GsAuth		*auth,
+gboolean	 gs_plugin_add_langpacks		(GsPlugin	*plugin,
+							 GsAppList	*list,
+							 const gchar    *locale,
 							 GCancellable	*cancellable,
 							 GError		**error);
 
 G_END_DECLS
-
-#endif /* __GS_PLUGIN_VFUNCS_H */
-
-/* vim: set noexpandtab: */
